﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
using Windows.Storage;
using Windows.Storage.Streams;

namespace fileOperatApp
{
    /// <summary>
    /// 可用于自身或导航至 Frame 内部的空白页。
    /// </summary>
    public sealed partial class Page3 : Page
    {
        public Page3()
        {
            this.InitializeComponent();
        }

        private async void OnWrite(object sender, RoutedEventArgs e)
        {
            string content = null;
            edit.Document.GetText(Windows.UI.Text.TextGetOptions.AdjustCrlf, out content);
            if (string.IsNullOrEmpty(content))
            {
                return;
            }
            Button b = sender as Button;
            b.IsEnabled = false;

            StorageFolder doclib = KnownFolders.DocumentsLibrary;
            StorageFile file = await doclib.CreateFileAsync("some.txt", CreationCollisionOption.ReplaceExisting);
            Tag = file.Name;
            using (IRandomAccessStream stream = await file.OpenAsync(FileAccessMode.ReadWrite))
            {
                // 转化为.net IO 流
                using (StreamWriter writer = new StreamWriter(stream.AsStreamForWrite(), System.Text.Encoding.UTF8))
                {
                    // 写入内容
                    writer.Write(content);
                }
            }

            b.IsEnabled = true;
        }

        private async void OnRead(object sender, RoutedEventArgs e)
        {
            string filename = Tag as string;
            if (string.IsNullOrEmpty(filename)) return;

            Button b = sender as Button;
            b.IsEnabled = false;

            StorageFolder doc = KnownFolders.DocumentsLibrary;
            try
            {
                StorageFile file = await doc.GetFileAsync(filename);
                using (IRandomAccessStream stream = await file.OpenReadAsync())
                {
                    using (StreamReader rd = new StreamReader(stream.AsStreamForRead(), System.Text.Encoding.UTF8))
                    {
                        tb.Text = rd.ReadToEnd();
                    }
                }
            }
            catch (FileNotFoundException)
            {
                tb.Text = "未找到文件。";
            }
            catch (Exception ex)
            {
                tb.Text = ex.Message;
            }

            b.IsEnabled = true;
        }
    }
}
